@@ -164,8 +164,7 @@ class FullFrequencySupportTool(Frame, WidgetWithMetadata):
 
         Parameters
         ----------
-        primary
-            tkinter.Tk|tkinter.TopLevel
+        primary : tkinter.Tk|tkinter.Toplevel
         reader : None|str|SICDTypeReader|SICDTypeCanvasImageReader
         kwargs
         """
